pub struct HeaderClient<'a> { /* private fields */ }
Client for working with the header ringbuffer

Implementations

Push a HashMap<String,String> into into the header ringbuffer

Safety

There are limitations on what can be a key and a value. For example, neither can contain spaces, tabs, newlines, #, or \0. We are not validating that here so you could end up with bad bytes in the end.

Get a reader for this HeaderClient. This is mutually exclusive with writer

Get a writer for this HeaderClient. This is mutually exclusive with reader