Struct psrdada::client::HeaderClient
source · pub struct HeaderClient<'a> { /* private fields */ }Expand description
Client for working with the header ringbuffer
Implementations
sourceimpl HeaderClient<'_>
impl HeaderClient<'_>
sourcepub unsafe fn push_header(
&mut self,
header: &HashMap<String, String>
) -> PsrdadaResult<usize>
pub unsafe fn push_header(
&mut self,
header: &HashMap<String, String>
) -> PsrdadaResult<usize>
Push a HashMap<String,String> into into the header ringbuffer
Safety
There are limitations on what can be a key and a value. For example, neither can contain spaces, tabs, newlines, #, or \0. We are not validating that here so you could end up with bad bytes in the end.
pub fn pop_header(&mut self) -> PsrdadaResult<HashMap<String, String>>